zipp: A pathlib-compatible zipfile object wrapper
=================================================

Description
-----------

A pathlib-compatible Zipfile object wrapper. A backport of the Path object.

License
-------

MIT License


Upstream Contact
----------------

Home page: https://github.com/jaraco/zipp

Dependencies
------------

Python, Setuptools
